@@ -19,8 +19,6 @@
 
 extern void vp8cx_mb_init_quantizer(VP8_COMP *cpi, MACROBLOCK *x, int ok_to_skip);
 
-extern void vp8_loopfilter_frame(VP8_COMP *cpi, VP8_COMMON *cm);
-
 static THREAD_FUNCTION thread_loopfilter(void *p_data)
 {
     VP8_COMP *cpi = (VP8_COMP *)(((LPFTHREAD_DATA *)p_data)->ptr1);
@@ -122,7 +120,7 @@ THREAD_FUNCTION thread_encoding_proc(void *p_data)
                         while (mb_col > (*last_row_current_mb_col - nsync))
                         {
                             x86_pause_hint();
-                            thread_sleep(1);
+                            thread_sleep(0);
                         }
                     }
 
@@ -573,7 +571,7 @@ int vp8cx_create_encoder_threads(VP8_COMP *cpi)
             ethd->ptr1 = (void *)cpi;
             ethd->ptr2 = (void *)&cpi->mb_row_ei[ithread];
 
-            rc = thread_create(&cpi->h_encoding_thread[ithread], 0,
+            rc = pthread_create(&cpi->h_encoding_thread[ithread], 0,
                                 thread_encoding_proc, ethd);
             if(rc)
                 break;
@@ -607,7 +605,7 @@ int vp8cx_create_encoder_threads(VP8_COMP *cpi)
             sem_init(&cpi->h_event_end_lpf, 0, 0);
 
             lpfthd->ptr1 = (void *)cpi;
-            rc = thread_create(&cpi->h_filter_thread, 0, thread_loopfilter,
+            rc = pthread_create(&cpi->h_filter_thread, 0, thread_loopfilter,
                                 lpfthd);
 
             if(rc)
